.. image:: gfx/logo.png
   :height: 512px
   :width: 512px
   :scale: 60 %
   :alt: PyScaffold logo
   :align: center

|

PyScaffold is a project generator for bootstrapping high-quality Python
packages, ready to be shared on PyPI_ and installable via pip_.
It is easy to use and encourages the adoption of the best tools and
practices of the Python ecosystem, helping you and your team
to stay sane, happy and productive. The best part? It is stable and has been used
by thousands of developers for over half a decade!

.. note::
   This document refers to the latest version of PyScaffold (v4).
   Please refer to `v3.3`_ for the previous stable version.
   Both versions are compatible with Python 3.6 and greater.

   For legacy Python 2.7 please install PyScaffold 2.5
   *(not officially supported)*.


Contents
--------

.. toctree::
   :maxdepth: 2

   Installation <install>
   Features <features>
   Usage & Examples <usage>
   Advanced Usage & Features <advanced>
   Why PyScaffold? <reasons>
   FAQ <faq>

.. toctree::
   :caption: Project
   :maxdepth: 2

   Contributions & Help <contributing>
   Developer Guide <dev-guide>
   Contributors <contributors>
   Changelog <changelog>
   License <license>
   Module Reference <api/modules>


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. _PyPI: https://pypi.org/
.. _pip: https://pip.pypa.io/en/stable/
.. _v3.3: https://pyscaffold.org/en/v3.3.x/
